import logging

logging.basicConfig()


changes = {
    # FIXME round number wrong
    #
    "staking_only": 100,
    # FIXME
    "reputation_bonus_0.1": 101,
    "staking_bonus_start": 154,
    "reputation_bonus_start": 158,
    "reputation_bonus_averaging": 164,
    "correlation_score_start": 168,
    }
